@@ -9,7 +9,7 @@ import sys
 
 # nipype version information
 # Remove -dev for release
-__version__ = '1.2.2'
+__version__ = '1.2.3'
 
 
 def get_nipype_gitversion():
@@ -164,6 +164,8 @@ REQUIRES = [
     'scipy>=%s,<%s ; python_version <= "3.4"' % (SCIPY_MIN_VERSION, SCIPY_MAX_VERSION_34),
     'simplejson>=%s' % SIMPLEJSON_MIN_VERSION,
     'traits>=%s,!=5.0' % TRAITS_MIN_VERSION,
+    'filelock>=3.0.0',
+    'etelemetry',
 ]
 
 # neurdflib has to come after prov
@@ -180,12 +182,13 @@ TESTS_REQUIRES = [
 ]
 
 EXTRA_REQUIRES = {
+    'data': ['datalad'],
     'doc': ['Sphinx>=1.4', 'numpydoc', 'matplotlib', 'pydotplus', 'pydot>=1.2.3'],
     'duecredit': ['duecredit'],
     'nipy': ['nitime', 'nilearn<0.5.0', 'dipy', 'nipy', 'matplotlib'],
     'profiler': ['psutil>=5.0'],
     'pybids': ['pybids>=0.7.0'],
-    'specs': ['yapf'],
+    'specs': ['yapf>=0.27'],
     'ssh': ['paramiko'],
     'tests': TESTS_REQUIRES,
     'xvfbwrapper': ['xvfbwrapper'],
