@@ -21,6 +21,7 @@ import shutil
 import contextlib
 import posixpath
 import simplejson as json
+from filelock import SoftFileLock
 
 from builtins import str, bytes, open
 
@@ -39,14 +40,16 @@ related_filetype_sets = [
 
 PY3 = sys.version_info[0] >= 3
 
+try:
+    from builtins import FileNotFoundError
+except ImportError:  # PY27
+    class FileNotFoundError(OSError):  # noqa
+        """Defines the exception for Python 2."""
 
-class FileNotFoundError(OSError):  # noqa
-    """Defines the exception for Python 2."""
-
-    def __init__(self, path):
-        """Initialize the exception."""
-        super(FileNotFoundError, self).__init__(
-            2, 'No such file or directory', '%s' % path)
+        def __init__(self, path):
+            """Initialize the exception."""
+            super(FileNotFoundError, self).__init__(
+                2, 'No such file or directory', '%s' % path)
 
 
 USING_PATHLIB2 = False
@@ -56,7 +59,7 @@ except ImportError:
     from pathlib2 import Path
     USING_PATHLIB2 = True
 
-try:
+try: # PY35 - strict mode was added in 3.6
     Path('/invented/file/path').resolve(strict=True)
 except TypeError:
     def _patch_resolve(self, strict=False):
@@ -72,6 +75,7 @@ except TypeError:
 except FileNotFoundError:
     pass
 except OSError:
+    # PY2
     def _patch_resolve(self, strict=False):
         """Raise FileNotFoundError instead of OSError with pathlib2."""
         try:
@@ -84,6 +88,26 @@ except OSError:
     Path.old_resolve = Path.resolve
     Path.resolve = _patch_resolve
 
+if not hasattr(Path, 'write_text'):
+    # PY34 - Path does not have write_text
+    def _write_text(self, text):
+        with open(str(self), 'w') as f:
+            f.write(text)
+    Path.write_text = _write_text
+
+try:  # PY27/PY34 - mkdir does not have exist_ok
+    from .tmpdirs import TemporaryDirectory
+    with TemporaryDirectory() as tmpdir:
+        (Path(tmpdir) / 'exist_ok_test').mkdir(exist_ok=True)
+except TypeError:
+    def _mkdir(self, mode=0o777, parents=False, exist_ok=False):
+        if parents:
+            makedirs(str(self), mode=mode, exist_ok=exist_ok)
+        elif not exist_ok or not self.exists():
+            os.mkdir(str(self), mode=mode)
+
+    Path.mkdir = _mkdir
+
 
 def split_filename(fname):
     """Split a filename into parts: path, base filename and extension.
@@ -684,36 +708,33 @@ def loadpkl(infile):
 
     unpkl = None
     with indirectory(infile.parent):
-        pkl_file = pklopen(infile.name, 'rb')
-
-        try:  # Look if pkl file contains version file
-            pkl_metadata_line = pkl_file.readline()
-            pkl_metadata = json.loads(pkl_metadata_line)
-        except (UnicodeDecodeError, json.JSONDecodeError):
-            # Could not get version info
-            pkl_file.seek(0)
-
-        try:
-            unpkl = pickle.load(pkl_file)
-        except UnicodeDecodeError:
-            # Was this pickle created with Python 2.x?
-            unpkl = pickle.load(pkl_file, fix_imports=True, encoding='utf-8')
-            fmlogger.info('Successfully loaded pkl in compatibility mode.')
-        # Unpickling problems
-        except Exception as e:
-            if pkl_metadata and 'version' in pkl_metadata:
-                from nipype import __version__ as version
-                if pkl_metadata['version'] != version:
-                    fmlogger.error("""\
+        with SoftFileLock('%s.lock' % infile.name):
+            with pklopen(infile.name, 'rb') as pkl_file:
+                try:  # Look if pkl file contains version file
+                    pkl_metadata_line = pkl_file.readline()
+                    pkl_metadata = json.loads(pkl_metadata_line)
+                except (UnicodeDecodeError, json.JSONDecodeError):
+                    # Could not get version info
+                    pkl_file.seek(0)
+                try:
+                    unpkl = pickle.load(pkl_file)
+                except UnicodeDecodeError:
+                    # Was this pickle created with Python 2.x?
+                    unpkl = pickle.load(pkl_file, fix_imports=True, encoding='utf-8')
+                    fmlogger.info('Successfully loaded pkl in compatibility mode.')
+                # Unpickling problems
+                except Exception as e:
+                    if pkl_metadata and 'version' in pkl_metadata:
+                        from nipype import __version__ as version
+                        if pkl_metadata['version'] != version:
+                            fmlogger.error("""\
 Attempted to open a results file generated by Nipype version %s, \
 with an incompatible Nipype version (%s)""", pkl_metadata['version'], version)
-                    raise e
-            fmlogger.error("""\
+                            raise e
+                    fmlogger.warning("""\
 No metadata was found in the pkl file. Make sure you are currently using \
 the same Nipype version from the generated pkl.""")
-            raise e
-        finally:
-            pkl_file.close()
+                    raise e
 
     if unpkl is None:
         raise ValueError('Loading %s resulted in None.' % infile)
@@ -754,20 +775,17 @@ def read_stream(stream, logger=None, encoding=None):
 
 
 def savepkl(filename, record, versioning=False):
-    if filename.endswith('pklz'):
-        pkl_file = gzip.open(filename, 'wb')
-    else:
-        pkl_file = open(filename, 'wb')
+    pklopen = gzip.open if filename.endswith('.pklz') else open
+    with SoftFileLock('%s.lock' % filename):
+        with pklopen(filename, 'wb') as pkl_file:
+            if versioning:
+                from nipype import __version__ as version
+                metadata = json.dumps({'version': version})
 
-    if versioning:
-        from nipype import __version__ as version
-        metadata = json.dumps({'version': version})
+                pkl_file.write(metadata.encode('utf-8'))
+                pkl_file.write('\n'.encode('utf-8'))
 
-        pkl_file.write(metadata.encode('utf-8'))
-        pkl_file.write('\n'.encode('utf-8'))
-
-    pickle.dump(record, pkl_file)
-    pkl_file.close()
+            pickle.dump(record, pkl_file)
 
 
 rst_levels = ['=', '-', '~', '+']
@@ -809,7 +827,7 @@ def dist_is_editable(dist):
     return False
 
 
-def makedirs(path, exist_ok=False):
+def makedirs(path, mode=0o777, exist_ok=False):
     """
     Create path, if it doesn't exist.
 
@@ -819,14 +837,14 @@ def makedirs(path, exist_ok=False):
 
     """
     if not exist_ok:  # The old makedirs
-        os.makedirs(path)
+        os.makedirs(path, mode=mode)
         return path
 
     # this odd approach deals with concurrent directory cureation
     if not op.exists(op.abspath(path)):
         fmlogger.debug("Creating directory %s", path)
         try:
-            os.makedirs(path)
+            os.makedirs(path, mode=mode)
         except OSError:
             fmlogger.debug("Problem creating directory %s", path)
             if not op.exists(path):
